@@ -467,6 +467,23 @@ hdy_window_mixin_draw (HdyWindowMixin *self,
   return GDK_EVENT_PROPAGATE;
 }
 
+void
+hdy_window_mixin_destroy (HdyWindowMixin *self)
+{
+  if (self->titlebar) {
+    hdy_window_mixin_remove (self, self->titlebar);
+    self->titlebar = NULL;
+  }
+
+  if (self->content) {
+    hdy_window_mixin_remove (self, self->content);
+    self->content = NULL;
+    self->child = NULL;
+  }
+
+  GTK_WIDGET_CLASS (self->klass)->destroy (GTK_WIDGET (self->window));
+}
+
 void
 hdy_window_mixin_buildable_add_child (HdyWindowMixin *self,
                                       GtkBuilder     *builder,
